import itertools

case_list = ['用户名', '密码']
value_list = ['正确', '不正确', '特殊符号', '超过最大长度']


def add_one(number):
    return number + 1

def gen_case(item=case_list, value=value_list):
    '''输出笛卡尔用例集合'''
    for i in itertools.product(item, value):
        print('输入'.join(i))

def test_print():
	    print("欢迎搜索关注公众号: 「测试开发技术」!")

if __name__ == '__main__':
    test_print()



#!/usr/bin/env python

import re
import setuptools

from distutils.core import setup
from setuptools import find_packages

version = "0.0.10"

with open("README.md", "r",encoding="utf-8") as f:
  long_description = f.read()

setuptools.setup(
    name="dknovautils",
    version=version,
    author="dknova",
    author_email="dknova@example.com",
    description="This is the tools for dknova.",
    long_description=long_description,
    # long_description_content_type="text/markdown",
    url="http://example.com",
    install_requires=[
        'requests!=2.9.0',
        'lxml>=4.2.3',
        'monotonic>=1.5',
    ],
    packages=setuptools.find_packages(exclude=("test")),
    classifiers=(
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",

        "Programming Language :: Python :: 3.7"
    ),
    exclude_package_data={'': ["*.txt","*.adoc","*.sh","dknovautils/test.py", "dknovautils/config.txt","dknovautils/*.sh","dknovautils/test*.py"]},
)
